@@ -4,7 +4,6 @@ function(para,nowarn=FALSE) {
     if(any(is.na(para$para))) return(FALSE)
 
     A <- para$para[2]
-    G <- para$para[3]
     op <- options()
     GO <- TRUE
     if(nowarn == TRUE) options(warn=-1)
@@ -12,10 +11,6 @@ function(para,nowarn=FALSE) {
       warning("Parameter A is not > 0, invalid")
       GO <- FALSE
     }
-    if(G <= -1) {
-      warning("Parameter G is not > -1, invalid")
-      GO <- FALSE
-    }
     options(op)
     if(GO) return(TRUE)
     return(FALSE)
