@@ -1,12 +1,14 @@
 "are.parnor.valid" <-
 function(para,nowarn=FALSE) {
     if(! is.nor(para)) return(FALSE)
+    if(any(is.na(para$para))) return(FALSE)
+
     sd <- para$para[2]
     op <- options()
     GO <- TRUE
     if(nowarn == TRUE) options(warn=-1)
     if(sd <= 0) {
-      warning("Parameters are invalid")
+      warning("Parameter sd is not > 0, invalid")
       GO <- FALSE
     }
     options(op)
