@@ -1,6 +1,8 @@
 "are.parrice.valid" <-
 function(para,nowarn=FALSE) {
     if(! is.rice(para)) return(FALSE)
+    if(any(is.na(para$para))) return(FALSE)
+
     V   <- para$para[1]
     A   <- para$para[2]
     SNR <- V/A
@@ -8,11 +10,11 @@ function(para,nowarn=FALSE) {
     GO <- TRUE
     if(nowarn == TRUE) options(warn=-1)
     if(A <= 0) {
-      warning("Parameter A is invalid")
+      warning("Parameter A is not > 0, invalid")
       GO <- FALSE
     }
     if(V < 0) { # V = 0 is Rayleigh
-      warning("Parameter V is invalid")
+      warning("Parameter V is not >= 0, invalid")
       GO <- FALSE
     }
     #if(SNR > 24) {
