@@ -1,6 +1,7 @@
 "are.parwei.valid" <-
 function(para,nowarn=FALSE) {
     if(! is.wei(para)) return(FALSE)
+    if(any(is.na(para$para))) return(FALSE)
 
     ZETA <- para$para[1]
     B <- para$para[2]
@@ -13,8 +14,12 @@ function(para,nowarn=FALSE) {
     op <- options()
     GO <- TRUE
     if(nowarn == TRUE) options(warn=-1)
-    if(A <= 0 | K <= -1) {
-      warning("Parameters are invalid")
+    if(A <= 0) {
+      warning("Parameter A is not > 0, invalid")
+      GO <- FALSE
+    }
+    if(K <= -1) {
+      warning("Parameter K is not > -1, invalid")
       GO <- FALSE
     }
     options(op)
