@@ -21,6 +21,7 @@ function(para) {
               0.150374992788438185, 
               0.558683500577583138e-1)
 
+    if(! are.pargum.valid(para)) return()
     attributes(para$para) <- NULL
 
     A <- para$para[2] 
@@ -33,6 +34,7 @@ function(para) {
     z$L3   <- z$TAU3*z$L2
     z$L4   <- z$TAU4*z$L2
     z$L5   <- z$TAU5*z$L2
+    z <- lmorph(z)
     return(z)
 }
 
