@@ -272,7 +272,7 @@ function(lmom, verbose=FALSE, initkh=NULL, eps=1e-3,
    REST <- BEST[-c(1),]
    rownames(REST) <- NULL
    # Preparing final best guess . . .
-   para <- vector(mode="numeric", length=4)
+   para <- rep(NA,4)
    names(para) <- c("xi","alpha","kappa","h")
    para[1]  <- BEST$xi[1]
    para[2]  <- BEST$alpha[1]
