@@ -3,9 +3,9 @@ function(lmom,...) {
     if(length(lmom$trim) == 1 && lmom$trim != 1) {
       warning("Attribute of TL-moments is not trim=1--can not complete parameter estimation")
       return()
-    }  
+    }
 
-   para <- vector(mode="numeric", length=3)
+   para <- rep(NA,3)
    names(para) <- c("xi","alpha","kappa")
 
    L1 <- lmom$lambdas[1]
@@ -14,7 +14,7 @@ function(lmom,...) {
 
    K <- (10-45*T3)/(9*T3+10)
    A <- (1/6)*L2*(K+2)*(K+3)*(K+4)
-   X <- L1 - A*(K+5)/((K+2)*(K+3)) 
+   X <- L1 - A*(K+5)/((K+2)*(K+3))
 
    para[1] <- X
    para[2] <- A
