@@ -6,10 +6,9 @@ function(f,para,paracheck=TRUE) {
     }
     U <- para$para[1]
     A <- para$para[2]
-    x <- vector(mode="numeric", length=length(f))
-    for(i in seq(1,length(f))) {
-      x[i] <- U-A*log(1-f[i])
-    }
+
+    x <- U-A*log(1-f)
+    names(x) <- NULL
     return(x)
 }
 
